@@ -7,6 +7,7 @@
 #' @param range_max_sigma define maximum in slider of sigma. must be positive.
 #' @param resolution resolution of slider
 #' @param return_param If return_param is TRUE, returns values of radius and sigma. If return_param is FALSE, returns a magick image object.
+#' @param scale geometry to be passed to image_scale function of magick package. image is scaled just for preview and result image is not scaled if scale is given.
 #' @return a magick image object or values of radius and sigma
 #' @author Shota Ochi
 #' @export
@@ -14,8 +15,16 @@
 #' \donttest{
 #' interactive_blur(wizard)
 #' }
-interactive_blur <- function(image, range_max_radius = 5, range_max_sigma = 5, resolution = 0.1, return_param = FALSE)
+interactive_blur <- function(image, range_max_radius = 5, range_max_sigma = 5, resolution = 0.1, return_param = FALSE, scale)
 {
+  # image must be convreted into png to avoid the error of tkimage.create function
+  image_original <- image
+  image <- image_convert(as.list(image)[[1]], format = "png")
+  if (!missing(scale))
+  {
+    image <- image_scale(image, scale)
+  }
+  
   # make initial output
   iniv <- 0
   initial <- image_blur(image, iniv, iniv)
@@ -94,7 +103,8 @@ interactive_blur <- function(image, range_max_radius = 5, range_max_sigma = 5, r
       error = function(e) assign("wait_test", TRUE, inherits = TRUE)
       )
     }
-    wait_time()
+    wait_time_long()
+    tkdestroy(win1.button)
   }
   tkwm.state(win1, "normal")
   while (TRUE)
@@ -122,5 +132,5 @@ interactive_blur <- function(image, range_max_radius = 5, range_max_sigma = 5, r
   {
     return(val_res)
   }
-  return(image_blur(image, val_res[1], val_res[2]))
+  return(image_blur(image_original, val_res[1], val_res[2]))
 }
